==> wildfly-config-api-0.2.1-sources.jar: org/wildfly/swarm/config/ejb3/subsystem/service/databaseDataStore/DatabaseDataStore.java <==
package org.wildfly.swarm.config.ejb3.subsystem.service.databaseDataStore;

import org.wildfly.apigen.invocation.Implicit;
import org.wildfly.apigen.invocation.Address;
import org.wildfly.apigen.invocation.Binding;
/**
 * An database based store for persistent EJB timers.
 */
@Address("/subsystem=ejb3/service=timer-service/database-data-store=*")
public class DatabaseDataStore {

	private String key;
	private Boolean allowExecution;
	private String database;
	private String datasourceJndiName;
	private String partition;
	private Integer refreshInterval;

	public DatabaseDataStore(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * If this node is allowed to execute timers. If this is false then the timers will be added to the database, and another node may execute them. Note that depending on your refresh interval if you add timers with a very short delay they will not be executed until another node refreshes.
	 */
	@Binding(detypedName = "allow-execution")
	public Boolean allowExecution() {
		return this.allowExecution;
	}

	/**
	 * If this node is allowed to execute timers. If this is false then the timers will be added to the database, and another node may execute them. Note that depending on your refresh interval if you add timers with a very short delay they will not be executed until another node refreshes.
	 */
	public DatabaseDataStore allowExecution(Boolean value) {
		this.allowExecution = value;
		return this;
	}

	/**
	 * The type of database that is in use. SQL can be customised per database type.
	 */
	@Binding(detypedName = "database")
	public String database() {
		return this.database;
	}

	/**
	 * The type of database that is in use. SQL can be customised per database type.
	 */
	public DatabaseDataStore database(String value) {
		this.database = value;
		return this;
	}

	/**
	 * The datasource that is used to persist the timers
	 */
	@Binding(detypedName = "datasource-jndi-name")
	public String datasourceJndiName() {
		return this.datasourceJndiName;
	}

	/**
	 * The datasource that is used to persist the timers
	 */
	public DatabaseDataStore datasourceJndiName(String value) {
		this.datasourceJndiName = value;
		return this;
	}

	/**
	 * The partition name. This should be set to a different value for every node that is sharing a database to prevent the same timer being loaded by multiple noded.
	 */
	@Binding(detypedName = "partition")
	public String partition() {
		return this.partition;
	}

	/**
	 * The partition name. This should be set to a different value for every node that is sharing a database to prevent the same timer being loaded by multiple noded.
	 */
	public DatabaseDataStore partition(String value) {
		this.partition = value;
		return this;
	}

	/**
	 * Interval between refreshing the current timer set against the underlying database. A low value means timers get picked up more quickly, but increase load on the database.
	 */
	@Binding(detypedName = "refresh-interval")
	public Integer refreshInterval() {
		return this.refreshInterval;
	}

	/**
	 * Interval between refreshing the current timer set against the underlying database. A low value means timers get picked up more quickly, but increase load on the database.
	 */
	public DatabaseDataStore refreshInterval(Integer value) {
		this.refreshInterval = value;
		return this;
	}
}

==> wildfly-config-api-0.2.2-sources.jar: org/wildfly/swarm/config/ejb3/subsystem/service/databaseDataStore/DatabaseDataStore.java <==
package org.wildfly.swarm.config.ejb3.subsystem.service.databaseDataStore;

import org.wildfly.apigen.invocation.Implicit;
import org.wildfly.apigen.invocation.Address;
import org.wildfly.apigen.invocation.Binding;
/**
 * An database based store for persistent EJB timers.
 */
@Address("/subsystem=ejb3/service=timer-service/database-data-store=*")
public class DatabaseDataStore<T extends DatabaseDataStore> {

	private String key;
	private Boolean allowExecution;
	private String database;
	private String datasourceJndiName;
	private String partition;
	private Integer refreshInterval;

	public DatabaseDataStore(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * If this node is allowed to execute timers. If this is false then the timers will be added to the database, and another node may execute them. Note that depending on your refresh interval if you add timers with a very short delay they will not be executed until another node refreshes.
	 */
	@Binding(detypedName = "allow-execution")
	public Boolean allowExecution() {
		return this.allowExecution;
	}

	/**
	 * If this node is allowed to execute timers. If this is false then the timers will be added to the database, and another node may execute them. Note that depending on your refresh interval if you add timers with a very short delay they will not be executed until another node refreshes.
	 */
	@SuppressWarnings("unchecked")
	public T allowExecution(Boolean value) {
		this.allowExecution = value;
		return (T) this;
	}

	/**
	 * The type of database that is in use. SQL can be customised per database type.
	 */
	@Binding(detypedName = "database")
	public String database() {
		return this.database;
	}

	/**
	 * The type of database that is in use. SQL can be customised per database type.
	 */
	@SuppressWarnings("unchecked")
	public T database(String value) {
		this.database = value;
		return (T) this;
	}

	/**
	 * The datasource that is used to persist the timers
	 */
	@Binding(detypedName = "datasource-jndi-name")
	public String datasourceJndiName() {
		return this.datasourceJndiName;
	}

	/**
	 * The datasource that is used to persist the timers
	 */
	@SuppressWarnings("unchecked")
	public T datasourceJndiName(String value) {
		this.datasourceJndiName = value;
		return (T) this;
	}

	/**
	 * The partition name. This should be set to a different value for every node that is sharing a database to prevent the same timer being loaded by multiple noded.
	 */
	@Binding(detypedName = "partition")
	public String partition() {
		return this.partition;
	}

	/**
	 * The partition name. This should be set to a different value for every node that is sharing a database to prevent the same timer being loaded by multiple noded.
	 */
	@SuppressWarnings("unchecked")
	public T partition(String value) {
		this.partition = value;
		return (T) this;
	}

	/**
	 * Interval between refreshing the current timer set against the underlying database. A low value means timers get picked up more quickly, but increase load on the database.
	 */
	@Binding(detypedName = "refresh-interval")
	public Integer refreshInterval() {
		return this.refreshInterval;
	}

	/**
	 * Interval between refreshing the current timer set against the underlying database. A low value means timers get picked up more quickly, but increase load on the database.
	 */
	@SuppressWarnings("unchecked")
	public T refreshInterval(Integer value) {
		this.refreshInterval = value;
		return (T) this;
	}
}
